import { StyleSheet } from 'fela-tools'
import { COLOR, EDGES, ICON } from '../../core/constants'
import { offset } from '../../core/utils'
import edges from '../../rules/edges/edges'
import text from '../../rules/text/text'

const HEIGHT = 32

export default StyleSheet.create({
  input: {
    position: 'relative',
    paddingTop: HEIGHT
  },
  label: ({ invalid, dirty }) => ({
    userSelect: 'none',
    position: 'absolute',
    top: 10,
    left: 0,
    extend: [
      text({
        color: dirty && invalid ? COLOR.CLAY : COLOR.SLATE
      })
    ]
  }),
  field: ({ invalid, dirty }) => ({
    display: 'block',
    boxSizing: 'border-box',
    outline: 'none',
    width: '100%',
    height: HEIGHT,
    border: {
      color: dirty
        ? invalid
          ? COLOR.CLAY
          : COLOR.LEAF
        : COLOR.STONE
    },
    placeholder: {
      color: COLOR.PLACEHOLDER
    },
    extend: [
      text(),
      edges({
        value: 8,
        edges: EDGES.LR,
        prefix: 'padding'
      })
    ],
    onFocus: {
      border: {
        color: dirty
          ? invalid
            ? COLOR.CLAY
            : COLOR.LEAF
          : COLOR.BLUE
      }
    }
  }),
  icon: ({ dirty }) => ({
    padding: offset(HEIGHT, ICON.SMALL),
    visibility: dirty ? 'visible' : 'hidden',
    position: 'absolute',
    left: '100%',
    top: HEIGHT
  }),
  error: {
    marginTop: 4
  }
})
