import { QUAD } from './easing'
import { hexToRgba } from './utils'

export const UNIT = 8

export const FONT = {

  FAMILY: {
    ICONS: 'Material Icons',
    PATHWAY: 'Pathway Gothic One',
    MONTSERRAT: 'Montserrat'
  },

  SIZE: {
    H1: '26px',
    H2: '22px',
    H3: '18px',
    BODY: '13px',
    META: '10px'
  },

  WEIGHT: {
    REGULAR: 400,
    BOLD: 600
  }
}

export const COLOR = {

  // Grey
  WHITE: '#FFFFFF', // Panels
  PAPER: '#FBFBFB', // Placeholder
  FROST: '#F3F4F5', // Background
  SMOKE: '#E5E7E9', // Menu
  STONE: '#D5D7D9', // Dividers
  STEEL: '#8888AA', // Meta
  SLATE: '#404045', // Text

  // Color
  CLAY: '#FF5A68', // Red
  RUST: '#FF976B', // Orange
  SAND: '#F3CF55', // Yellow
  LEAF: '#7FD280', // Green
  TEAL: '#68CFC9', // Teal
  BLUE: '#45B0E6', // Blue
  PLUM: '#897CB8', // Purple

  // Named
  TRANSPARENT: 'transparent',
  CURRENT: 'currentColor'
}

// Alpha
COLOR.SHADOW = hexToRgba(COLOR.SLATE, 0.25)
COLOR.BLACKOUT = hexToRgba(COLOR.SLATE, 0.5)
COLOR.PLACEHOLDER = hexToRgba(COLOR.SLATE, 0.5)

export const SPACING = {
  DESKTOP: 24,
  TABLET: 16,
  MOBILE: 12
}

export const BREAKPOINT = {
  MOBILE: 400,
  PHABLET: 560,
  TABLET: 720,
  DESKTOP: 960,
  CINEMA: 1200,
  ULTRA: 1400
}

export const BUTTON = {
  HEIGHT_LARGE: 40,
  HEIGHT_SMALL: 32,
  BORDER_WIDTH: 1
}

export const HEADER = {
  HEIGHT_SMALL: 56,
  HEIGHT_LARGE: 72
}

export const BLIP = {
  SIZE: 18,
  RING: 4
}

export const ICON = {
  MICRO: 18,
  SMALL: 24,
  MEDIUM: 36,
  LARGE: 48
}

export const APP = {
  MIN_WIDTH: 320
}

export const MENU = {
  WIDTH: 240,
  NAV_PADDING: 16,
  LINK_HEIGHT: 56,
  LINK_PADDING: 16
}

export const EDGES = {
  ALL: [ 'top', 'right', 'bottom', 'left' ],
  BR: [ 'bottom', 'right' ],
  BL: [ 'bottom', 'left' ],
  LR: [ 'left', 'right' ],
  TB: [ 'top', 'bottom' ],
  TR: [ 'top', 'right' ],
  TL: [ 'top', 'left' ],
  B: [ 'bottom' ],
  R: [ 'right' ],
  L: [ 'left' ],
  T: [ 'top' ]
}

export const TRANSITION = {
  UI: {
    duration: '0.2s',
    easing: QUAD.OUT
  }
}

export const TWEEN = {
  MENU: {
    duration: 500,
    easing: 'easeInOutCubic'
  }
}
